##----------------------------------------------------------------------------
## Copyright (c) Axis Communications AB, SWEDEN. All rights reserved.
##----------------------------------------------------------------------------

<#
    .SYNOPSIS
     Add component string constants to this file.
     Update this template if you are adding to this repo.
     This file should be placed in the solution root.
#>

# Version constants for the component
$ComponentVersions = @{
    axisBuildBootstrapVersion = "4.0.0"
    nugetScriptVersion        = "5.0.1"

    # bundled    = "1.1.0"
    # notBundled = "0.1.0"
    # legacy     = "1.0.0"
    componentBaseVersion      = "0.1.0"
}

# Name of script nuget
$NugetScriptConstants = @{
    nugetName                 = "Axis.Component.Scripts"
    nugetScriptsPath          = "BuildScripts"
    nugetRestoreUri           = "https://artifacts.se.axis.com/artifactory/api/nuget/v3/vms-nuget-all-se/index.json"
    nugetModulesDirectoryName = "Tools"
    nugetLoadModulesFileName  = "Load-ScriptModules.ps1"
}

# Solution specific constants
$SolutionConstants = [ordered]@{
    componentSolutionPath                = ($componentSolutionPath = $PSScriptRoot)
    projectName                          = ($projectName = "BWC.In.Car")
    projectPath                          = ($projectPath = Join-Path $componentSolutionPath $projectName)
    metadataFilePath                     = Join-Path $projectPath "metadata.json"
    metadataId                           = "axiseventbridgeforonlogic" # Should not change between versions
    metadataIdCamelCase                  = "AxisEventBridgeForOnlogic" # For naming conventions
    metaDataName                         = "AXIS Event Bridge for OnLogic"
    solutionName                         = ($solutionName = "BWC.In.Car")
    stringConstantsFilePath              = Join-Path $componentSolutionPath "StringConstants.ps1" # Place in solution root
    solutionFilePath                     = "$(Join-Path $componentSolutionPath $solutionName).sln"
    componentCsprojFilePath              = "$(Join-Path $projectPath $projectName).csproj"
    componentFilesToIncludeInPackagePath = Join-Path $componentSolutionPath "ComponentFilesToZip"
    packageJsonPath                      = Join-Path $projectPath "wwwroot\package.json"
    acsScriptsDirectoryPath              = Join-Path $projectPath "AcsScripts"

    binaryFile                           = "BWC.In.Car.exe" # improve
}

# Component nuget constants
$componentNugetConstants = [ordered]@{
    # Nuget-package naming conventions https://confluence.se.axis.com/pages/viewpage.action?spaceKey=MS&title=How+to+create+a+component+NuGet-package
    nuspecId                 = ($nuspecId = "Axis.Acs.Component.$($SolutionConstants.metadataIdCamelCase)")
    description              = "AXIS Event Bridge for OnLogic."
    signedComponentFileName  = "Signed$($SolutionConstants.metadataIdCamelCase).zip"
    nuspecFileName           = ($nuspecFileName = "$nuspecId.nuspec")
    targetsFileName          = ($targetsFileName = "$nuspecId.targets")
    nuspecFilePath           = Join-Path $SolutionConstants.projectPath $nuspecFileName
    targetsFilePath          = Join-Path $SolutionConstants.projectPath $targetsFileName

    # Each ACS component's SBOM file shall be named <ComponentName>_sbom.<format>.json (component name in pascal case and rest in lower case, format being e.g. "cyclonedx" or "spdx")  
    sbomFileBackEndName      = ($sbomFileBackEndName = "$($SolutionConstants.metadataIdCamelCase)_service_sbom.cyclonedx.json")
    sbomFileFrontEndName     = ($sbomFileFrontEndName = "$($SolutionConstants.metadataIdCamelCase)_ui_sbom.cyclonedx.json")
    sbomFileBackEndFilePath  = Join-Path $SolutionConstants.componentFilesToIncludeInPackagePath $sbomFileBackEndName
    sbomFileFrontEndFilePath = Join-Path $SolutionConstants.componentFilesToIncludeInPackagePath $sbomFileFrontEndName
}

# Service Specific Constants
$ServiceConstants = @{
    serviceName        = "AXISCameraStationEventBridgeForOnLogicService"
    serviceDisplayName = "AXIS Camera Station Event Bridge for OnLogic Service"
    serviceStartupType = "Manual"
    serviceDescription = "AXIS Camera Station Event Bridge for OnLogic Service"
}

# Constants used for packing and publishing
$componentPublishConstants = [ordered]@{
    componentSignUri        = "https://acs-plugin-sign.se.axis.com/sign"
    componentSignHeader     = "Basic ${env:AcsSigningAuthenticationToken}"
    zippedComponentFilePath = ($zippedComponentFilePath = "$(Join-Path $SolutionConstants.componentSolutionPath $SolutionConstants.metadataIdCamelCase).zip")
    componentSignFormData   = "plugin=@$zippedComponentFilePath"
    signedComponentFilePath = Join-Path $SolutionConstants.componentFilesToIncludeInPackagePath $componentNugetConstants.signedComponentFileName
    nugetPackageExePath     = "$env:SATOOLS\nuget6.exe"
}

# Third party specific constants
$ThirdPartyLicenseConstants = [ordered]@{
    licenseName                   = ($licenseName = "third-party-licenses")
    licenseFileName               = ($licenseFileName = "$licenseName.txt")
    thirdPartyLicenseTxtFilePath  = Join-Path $SolutionConstants.componentSolutionPath $licenseFileName
    thirdPartyLicenseJsonFilePath = Join-Path $SolutionConstants.componentSolutionPath "$licenseName.json"
}

$fileStructureConstants = @{
    dataDirPathName = "Data"
    logDirPathName  = "Logs"
    scriptLogName   = "scripts.log"
}

# Project GUIDs  to exclude from the SBOM
#
# Each project is declared with the following syntax in the solution file:
#
# Project("{<project type GUID>}") = "<project name>", "<project file location>", "{<project GUID>}"
# EndProject
$projectIdsToExclude = @(
    "5704B248-CB26-4EB6-98B9-79DCFF46175D" # TestProj
)
# SIG # Begin signature block
# MIIoIgYJKoZIhvcNAQcCoIIoEzCCKA8CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB3YRILOiwQICvZ
# MiUV7kbxf9YkyOM9wJj8i6lHs4QYkqCCDY4wggawMIIEmKADAgECAhAIrUCyYNKc
# TJ9ezam9k67ZMA0GCSqGSIb3DQEBDAUAMGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQK
# EwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xITAfBgNV
# BAMTGERpZ2lDZXJ0IFRydXN0ZWQgUm9vdCBHNDAeFw0yMTA0MjkwMDAwMDBaFw0z
# NjA0MjgyMzU5NTlaMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAw
# ggIKAoICAQDVtC9C0CiteLdd1TlZG7GIQvUzjOs9gZdwxbvEhSYwn6SOaNhc9es0
# JAfhS0/TeEP0F9ce2vnS1WcaUk8OoVf8iJnBkcyBAz5NcCRks43iCH00fUyAVxJr
# Q5qZ8sU7H/Lvy0daE6ZMswEgJfMQ04uy+wjwiuCdCcBlp/qYgEk1hz1RGeiQIXhF
# LqGfLOEYwhrMxe6TSXBCMo/7xuoc82VokaJNTIIRSFJo3hC9FFdd6BgTZcV/sk+F
# LEikVoQ11vkunKoAFdE3/hoGlMJ8yOobMubKwvSnowMOdKWvObarYBLj6Na59zHh
# 3K3kGKDYwSNHR7OhD26jq22YBoMbt2pnLdK9RBqSEIGPsDsJ18ebMlrC/2pgVItJ
# wZPt4bRc4G/rJvmM1bL5OBDm6s6R9b7T+2+TYTRcvJNFKIM2KmYoX7BzzosmJQay
# g9Rc9hUZTO1i4F4z8ujo7AqnsAMrkbI2eb73rQgedaZlzLvjSFDzd5Ea/ttQokbI
# YViY9XwCFjyDKK05huzUtw1T0PhH5nUwjewwk3YUpltLXXRhTT8SkXbev1jLchAp
# QfDVxW0mdmgRQRNYmtwmKwH0iU1Z23jPgUo+QEdfyYFQc4UQIyFZYIpkVMHMIRro
# OBl8ZhzNeDhFMJlP/2NPTLuqDQhTQXxYPUez+rbsjDIJAsxsPAxWEQIDAQABo4IB
# WTCCAVUwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQUaDfg67Y7+F8Rhvv+
# YXsIiGX0TkIwHwYDVR0jBBgwFoAU7NfjgtJxXWRM3y5nP+e6mK4cD08wDgYDVR0P
# AQH/BAQDAgGGMBMGA1UdJQQMMAoGCCsGAQUFBwMDMHcGCCsGAQUFBwEBBGswaTAk
# BggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEEGCCsGAQUFBzAC
# hjVodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkUm9v
# dEc0LmNydDBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8vY3JsMy5kaWdpY2VydC5j
# b20vRGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNybDAcBgNVHSAEFTATMAcGBWeBDAED
# MAgGBmeBDAEEATANBgkqhkiG9w0BAQwFAAOCAgEAOiNEPY0Idu6PvDqZ01bgAhql
# +Eg08yy25nRm95RysQDKr2wwJxMSnpBEn0v9nqN8JtU3vDpdSG2V1T9J9Ce7FoFF
# UP2cvbaF4HZ+N3HLIvdaqpDP9ZNq4+sg0dVQeYiaiorBtr2hSBh+3NiAGhEZGM1h
# mYFW9snjdufE5BtfQ/g+lP92OT2e1JnPSt0o618moZVYSNUa/tcnP/2Q0XaG3Ryw
# YFzzDaju4ImhvTnhOE7abrs2nfvlIVNaw8rpavGiPttDuDPITzgUkpn13c5Ubdld
# AhQfQDN8A+KVssIhdXNSy0bYxDQcoqVLjc1vdjcshT8azibpGL6QB7BDf5WIIIJw
# 8MzK7/0pNVwfiThV9zeKiwmhywvpMRr/LhlcOXHhvpynCgbWJme3kuZOX956rEnP
# LqR0kq3bPKSchh/jwVYbKyP/j7XqiHtwa+aguv06P0WmxOgWkVKLQcBIhEuWTatE
# QOON8BUozu3xGFYHKi8QxAwIZDwzj64ojDzLj4gLDb879M4ee47vtevLt/B3E+bn
# KD+sEq6lLyJsQfmCXBVmzGwOysWGw/YmMwwHS6DTBwJqakAwSEs0qFEgu60bhQji
# WQ1tygVQK+pKHJ6l/aCnHwZ05/LWUpD9r4VIIflXO7ScA+2GRfS0YW6/aOImYIbq
# yK+p/pQd52MbOoZWeE4wggbWMIIEvqADAgECAhAILYwW0nV0JkMDtityXUvoMA0G
# CSqGSIb3DQEBCwUAMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwHhcNMjQwMjEyMDAwMDAwWhcNMjcwMjEx
# MjM1OTU5WjBeMQswCQYDVQQGEwJTRTENMAsGA1UEBxMETHVuZDEfMB0GA1UEChMW
# QXhpcyBDb21tdW5pY2F0aW9ucyBBQjEfMB0GA1UEAxMWQXhpcyBDb21tdW5pY2F0
# aW9ucyBBQjCCAaIwDQYJKoZIhvcNAQEBBQADggGPADCCAYoCggGBAOk0Sr22C6QH
# zDpps6p3+m4c4HrGKW9dju1+awvCWpNnrTrCxxcqC7Fexgt3VVR2GfI+hEHrkSV9
# hq7tCT20No1s4OqGdB/FasUvqq8jCuoXKQQnd5gqFhFz/aL+1ocr2NvtCsxuNihB
# UA3isiFf0R0uXcEIoi+tUiy0vJf5ZstopMEuSSOZlANhdWvwBTd8DL1EBYDp4Z/t
# 1kWLax6NI8fim1MJxi5OaVUd1haFQMbzeBiwDXlMVJCyYcSVH7fuKCRhoem4pX1g
# fdbM3yfhigegJPRui13ai6I69X71GoyRCBnkCgkrw8nUrOHGjrTe90sXLvVSU0Yu
# j3VZzcDkdxN16tHG2SK3NT/7d5EmgrUSwabvS36sTRy0VeSCmop4ByDlTUCljGiP
# cDO5viiyDF9SRbKa0BSuVAB9xtaaqjw9+sWRxiUqHVq8cRPOylBcziOMVFSE4ENc
# aH3A55N2kb2tBalRm0GPfvB1wRzHdow/ArdGYB1FYIrBi2IUcUsgKwIDAQABo4IC
# AzCCAf8wHwYDVR0jBBgwFoAUaDfg67Y7+F8Rhvv+YXsIiGX0TkIwHQYDVR0OBBYE
# FCCITo81URSaUaiF+AwqLquw/5UcMD4GA1UdIAQ3MDUwMwYGZ4EMAQQBMCkwJwYI
# KwYBBQUHAgEWG2h0dHA6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAOBgNVHQ8BAf8E
# BAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMwgbUGA1UdHwSBrTCBqjBToFGgT4ZN
# aHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZEc0Q29kZVNp
# Z25pbmdSU0E0MDk2U0hBMzg0MjAyMUNBMS5jcmwwU6BRoE+GTWh0dHA6Ly9jcmw0
# LmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRHNENvZGVTaWduaW5nUlNBNDA5
# NlNIQTM4NDIwMjFDQTEuY3JsMIGUBggrBgEFBQcBAQSBhzCBhDAkBggrBgEFBQcw
# AYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMFwGCCsGAQUFBzAChlBodHRwOi8v
# Y2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkRzRDb2RlU2lnbmlu
# Z1JTQTQwOTZTSEEzODQyMDIxQ0ExLmNydDAJBgNVHRMEAjAAMA0GCSqGSIb3DQEB
# CwUAA4ICAQBTl/rp/1EMC6RXuNwZmY8QNQpzSOODOmLbFU1hMlHq/iipWO+tsAnH
# fB4CnZlrbgkVa64syckD29gWMrYp2PMdTwsL/vHmUI0lZj1pJ3zCvB5E+4CnKkhY
# SIre1yukMyzbHR5y5X2bQ6kVtR0mkKqDTrT+vm6abBMmNcVwc+j5IJ9viHspncAs
# X/t7gnYDmMnHCWTQwR01wNYypEbmpf5ZtF8233I5toy+x2TGBx7PToduYzxWiF9G
# Hd18UNGuyNjsLPnHI0cY3vGNMo5GiaisR9e/CHYUq149MduRRifz9kkq8JA81k0j
# +DEsZb8lOORoA7gte007xnesv35OL4ezbfhjkKYICGjRVSB/Xu8YhH04Xs6AbFWB
# Boqi9/DH9RV3S0LH+JzxNIeDUw8LW7VNYrSOHWuRqPSazmtWll+MQUDV0p4LIUMl
# EjoUNsRBvsDYSMiZSTNizMgyp437XDv25+iO8GMtiKlymsOPuKYALFVn0TJxdIet
# ID0HnXa560C3FysEDxsGbVCI6L1l9j5RCmmF1qUs7o2oczvlDyplesA0sNOSlpJF
# xyTgvlXXloxJCH7Yaz/2ItvhfMt1CZhMtyp38Y1yWlgMqSTrlJVxAcXHOXzu/mEM
# aNvDTqF/zGnW5todKFHL092hQqm+8xGNOjL0C8G+ByZ2tzSh3y1R7jGCGeowghnm
# AgEBMH0waTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDkRpZ2lDZXJ0LCBJbmMuMUEw
# PwYDVQQDEzhEaWdpQ2VydCBUcnVzdGVkIEc0IENvZGUgU2lnbmluZyBSU0E0MDk2
# IFNIQTM4NCAyMDIxIENBMQIQCC2MFtJ1dCZDA7Yrcl1L6DANBglghkgBZQMEAgEF
# AKB8MBAGCisGAQQBgjcCAQwxAjAAMBkGCSqGSIb3DQEJAzEMBgorBgEEAYI3AgEE
# MBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEiBCCI
# R4Fs1Xlk6tldMaAl9oBbQXDSucp+NBLYtSCA54FSsTANBgkqhkiG9w0BAQEFAASC
# AYDPY6aaR85wlCR5C7ZkbX24xcMmuCDfgoz+ozSWJVWMjhDYg4wqbCBcG5Ka+Oja
# 5OvQt34wgIi26WML822viP3zxilPanB8/y+1E/ch1APZovYYzmypG9hx4TSRwZH5
# lsEZpahbjtsbWpdrVCAVj4tHddWphuir5BObEiF9j6SEX6kJRk1u7b9WN7tePO35
# av7q+lOkha1Tf97+l2gTaj/d5DAA+0GYZhpGMqAAUj99AHEi5AoDc+WkOlzNJZDF
# khBDselHgANDOuMRwGd1/Q82uniXZ6Fgwh04Mr+G7uAe+7nqNvv/9CX13MTOxyOr
# kbOhT1Ww2muKE5/XV86mfJtNyoYakZACgkCiCmJSIuw4allNCe98YZhk19why38S
# zNZaG2q5tM6JonCmh5F8NSkOQQwGoCjY9rffGxRnmJEUgrD7+dqJaRR8uarn7M7c
# 6NGV79XLyqaj4Wk9YseE+lf7JbUgzsy7rFjkBr2HcYXHwekEXLIOOrgClnlUNGQj
# Qy6hghdAMIIXPAYKKwYBBAGCNwMDATGCFywwghcoBgkqhkiG9w0BBwKgghcZMIIX
# FQIBAzEPMA0GCWCGSAFlAwQCAQUAMHgGCyqGSIb3DQEJEAEEoGkEZzBlAgEBBglg
# hkgBhv1sBwEwMTANBglghkgBZQMEAgEFAAQgQB2w/ENLeyqfl0HyzDAJDyJLLAK5
# /k9PBYrDDV6JO4gCEQCRMTfYGUq+DCmvu2/fQdniGA8yMDI0MDkyMDA5NTUzOFqg
# ghMJMIIGwjCCBKqgAwIBAgIQBUSv85SdCDmmv9s/X+VhFjANBgkqhkiG9w0BAQsF
# ADBjMQswCQYDVQQGEwJVUzEXMBUGA1UEChMORGlnaUNlcnQsIEluYy4xOzA5BgNV
# BAMTMkRpZ2lDZXJ0IFRydXN0ZWQgRzQgUlNBNDA5NiBTSEEyNTYgVGltZVN0YW1w
# aW5nIENBMB4XDTIzMDcxNDAwMDAwMFoXDTM0MTAxMzIzNTk1OVowSDELMAkGA1UE
# BhMCVVMxFzAVBgNVBAoTDkRpZ2lDZXJ0LCBJbmMuMSAwHgYDVQQDExdEaWdpQ2Vy
# dCBUaW1lc3RhbXAgMjAyMzCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
# AKNTRYcdg45brD5UsyPgz5/X5dLnXaEOCdwvSKOXejsqnGfcYhVYwamTEafNqrJq
# 3RApih5iY2nTWJw1cb86l+uUUI8cIOrHmjsvlmbjaedp/lvD1isgHMGXlLSlUIHy
# z8sHpjBoyoNC2vx/CSSUpIIa2mq62DvKXd4ZGIX7ReoNYWyd/nFexAaaPPDFLnkP
# G2ZS48jWPl/aQ9OE9dDH9kgtXkV1lnX+3RChG4PBuOZSlbVH13gpOWvgeFmX40Qr
# StWVzu8IF+qCZE3/I+PKhu60pCFkcOvV5aDaY7Mu6QXuqvYk9R28mxyyt1/f8O52
# fTGZZUdVnUokL6wrl76f5P17cz4y7lI0+9S769SgLDSb495uZBkHNwGRDxy1Uc2q
# TGaDiGhiu7xBG3gZbeTZD+BYQfvYsSzhUa+0rRUGFOpiCBPTaR58ZE2dD9/O0V6M
# qqtQFcmzyrzXxDtoRKOlO0L9c33u3Qr/eTQQfqZcClhMAD6FaXXHg2TWdc2PEnZW
# pST618RrIbroHzSYLzrqawGw9/sqhux7UjipmAmhcbJsca8+uG+W1eEQE/5hRwqM
# /vC2x9XH3mwk8L9CgsqgcT2ckpMEtGlwJw1Pt7U20clfCKRwo+wK8REuZODLIivK
# 8SgTIUlRfgZm0zu++uuRONhRB8qUt+JQofM604qDy0B7AgMBAAGjggGLMIIBhzAO
# BgNVHQ8BAf8EBAMCB4AwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEF
# BQcDCDAgBgNVHSAEGTAXMAgGBmeBDAEEAjALBglghkgBhv1sBwEwHwYDVR0jBBgw
# FoAUuhbZbU2FL3MpdpovdYxqII+eyG8wHQYDVR0OBBYEFKW27xPn783QZKHVVqll
# MaPe1eNJMFoGA1UdHwRTMFEwT6BNoEuGSWh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNv
# bS9EaWdpQ2VydFRydXN0ZWRHNFJTQTQwOTZTSEEyNTZUaW1lU3RhbXBpbmdDQS5j
# cmwwgZAGCCsGAQUFBwEBBIGDMIGAMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5k
# aWdpY2VydC5jb20wWAYIKwYBBQUHMAKGTGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0
# LmNvbS9EaWdpQ2VydFRydXN0ZWRHNFJTQTQwOTZTSEEyNTZUaW1lU3RhbXBpbmdD
# QS5jcnQwDQYJKoZIhvcNAQELBQADggIBAIEa1t6gqbWYF7xwjU+KPGic2CX/yyzk
# zepdIpLsjCICqbjPgKjZ5+PF7SaCinEvGN1Ott5s1+FgnCvt7T1IjrhrunxdvcJh
# N2hJd6PrkKoS1yeF844ektrCQDifXcigLiV4JZ0qBXqEKZi2V3mP2yZWK7Dzp703
# DNiYdk9WuVLCtp04qYHnbUFcjGnRuSvExnvPnPp44pMadqJpddNQ5EQSviANnqlE
# 0PjlSXcIWiHFtM+YlRpUurm8wWkZus8W8oM3NG6wQSbd3lqXTzON1I13fXVFoaVY
# JmoDRd7ZULVQjK9WvUzF4UbFKNOt50MAcN7MmJ4ZiQPq1JE3701S88lgIcRWR+3a
# EUuMMsOI5ljitts++V+wQtaP4xeR0arAVeOGv6wnLEHQmjNKqDbUuXKWfpd5OEhf
# ysLcPTLfddY2Z1qJ+Panx+VPNTwAvb6cKmx5AdzaROY63jg7B145WPR8czFVoIAR
# yxQMfq68/qTreWWqaNYiyjvrmoI1VygWy2nyMpqy0tg6uLFGhmu6F/3Ed2wVbK6r
# r3M66ElGt9V/zLY4wNjsHPW2obhDLN9OTH0eaHDAdwrUAuBcYLso/zjlUlrWrBci
# I0707NMX+1Br/wd3H3GXREHJuEbTbDJ8WC9nR2XlG3O2mflrLAZG70Ee8PBf4NvZ
# rZCARK+AEEGKMIIGrjCCBJagAwIBAgIQBzY3tyRUfNhHrP0oZipeWzANBgkqhkiG
# 9w0BAQsFADBiMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkw
# FwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSEwHwYDVQQDExhEaWdpQ2VydCBUcnVz
# dGVkIFJvb3QgRzQwHhcNMjIwMzIzMDAwMDAwWhcNMzcwMzIyMjM1OTU5WjBjMQsw
# CQYDVQQGEwJVUzEXMBUGA1UEChMORGlnaUNlcnQsIEluYy4xOzA5BgNVBAMTMkRp
# Z2lDZXJ0IFRydXN0ZWQgRzQgUlNBNDA5NiBTSEEyNTYgVGltZVN0YW1waW5nIENB
# MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxoY1BkmzwT1ySVFVxyUD
# xPKRN6mXUaHW0oPRnkyibaCwzIP5WvYRoUQVQl+kiPNo+n3znIkLf50fng8zH1AT
# CyZzlm34V6gCff1DtITaEfFzsbPuK4CEiiIY3+vaPcQXf6sZKz5C3GeO6lE98NZW
# 1OcoLevTsbV15x8GZY2UKdPZ7Gnf2ZCHRgB720RBidx8ald68Dd5n12sy+iEZLRS
# 8nZH92GDGd1ftFQLIWhuNyG7QKxfst5Kfc71ORJn7w6lY2zkpsUdzTYNXNXmG6jB
# ZHRAp8ByxbpOH7G1WE15/tePc5OsLDnipUjW8LAxE6lXKZYnLvWHpo9OdhVVJnCY
# Jn+gGkcgQ+NDY4B7dW4nJZCYOjgRs/b2nuY7W+yB3iIU2YIqx5K/oN7jPqJz+ucf
# WmyU8lKVEStYdEAoq3NDzt9KoRxrOMUp88qqlnNCaJ+2RrOdOqPVA+C/8KI8ykLc
# GEh/FDTP0kyr75s9/g64ZCr6dSgkQe1CvwWcZklSUPRR8zZJTYsg0ixXNXkrqPNF
# YLwjjVj33GHek/45wPmyMKVM1+mYSlg+0wOI/rOP015LdhJRk8mMDDtbiiKowSYI
# +RQQEgN9XyO7ZONj4KbhPvbCdLI/Hgl27KtdRnXiYKNYCQEoAA6EVO7O6V3IXjAS
# vUaetdN2udIOa5kM0jO0zbECAwEAAaOCAV0wggFZMBIGA1UdEwEB/wQIMAYBAf8C
# AQAwHQYDVR0OBBYEFLoW2W1NhS9zKXaaL3WMaiCPnshvMB8GA1UdIwQYMBaAFOzX
# 44LScV1kTN8uZz/nupiuHA9PMA4GA1UdDwEB/wQEAwIBhjATBgNVHSUEDDAKBggr
# BgEFBQcDCDB3BggrBgEFBQcBAQRrMGkwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3Nw
# LmRpZ2ljZXJ0LmNvbTBBBggrBgEFBQcwAoY1aHR0cDovL2NhY2VydHMuZGlnaWNl
# cnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZFJvb3RHNC5jcnQwQwYDVR0fBDwwOjA4oDag
# NIYyaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZFJvb3RH
# NC5jcmwwIAYDVR0gBBkwFzAIBgZngQwBBAIwCwYJYIZIAYb9bAcBMA0GCSqGSIb3
# DQEBCwUAA4ICAQB9WY7Ak7ZvmKlEIgF+ZtbYIULhsBguEE0TzzBTzr8Y+8dQXeJL
# Kftwig2qKWn8acHPHQfpPmDI2AvlXFvXbYf6hCAlNDFnzbYSlm/EUExiHQwIgqgW
# valWzxVzjQEiJc6VaT9Hd/tydBTX/6tPiix6q4XNQ1/tYLaqT5Fmniye4Iqs5f2M
# vGQmh2ySvZ180HAKfO+ovHVPulr3qRCyXen/KFSJ8NWKcXZl2szwcqMj+sAngkSu
# mScbqyQeJsG33irr9p6xeZmBo1aGqwpFyd/EjaDnmPv7pp1yr8THwcFqcdnGE4AJ
# xLafzYeHJLtPo0m5d2aR8XKc6UsCUqc3fpNTrDsdCEkPlM05et3/JWOZJyw9P2un
# 8WbDQc1PtkCbISFA0LcTJM3cHXg65J6t5TRxktcma+Q4c6umAU+9Pzt4rUyt+8SV
# e+0KXzM5h0F4ejjpnOHdI/0dKNPH+ejxmF/7K9h+8kaddSweJywm228Vex4Ziza4
# k9Tm8heZWcpw8De/mADfIBZPJ/tgZxahZrrdVcA6KYawmKAr7ZVBtzrVFZgxtGIJ
# Dwq9gdkT/r+k0fNX2bwE+oLeMt8EifAAzV3C+dAjfwAL5HYCJtnwZXZCpimHCUcr
# 5n8apIUP/JiW9lVUKx+A+sDyDivl1vupL0QVSucTDh3bNzgaoSv27dZ8/DCCBY0w
# ggR1oAMCAQICEA6bGI750C3n79tQ4ghAGFowDQYJKoZIhvcNAQEMBQAwZTELMAkG
# A1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRp
# Z2ljZXJ0LmNvbTEkMCIGA1UEAxMbRGlnaUNlcnQgQXNzdXJlZCBJRCBSb290IENB
# MB4XDTIyMDgwMTAwMDAwMFoXDTMxMTEwOTIzNTk1OVowYjELMAkGA1UEBhMCVVMx
# FTATBgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNv
# bTEhMB8GA1UEAxMYRGlnaUNlcnQgVHJ1c3RlZCBSb290IEc0MIICIjANBgkqhkiG
# 9w0BAQEFAAOCAg8AMIICCgKCAgEAv+aQc2jeu+RdSjwwIjBpM+zCpyUuySE98orY
# WcLhKac9WKt2ms2uexuEDcQwH/MbpDgW61bGl20dq7J58soR0uRf1gU8Ug9SH8ae
# FaV+vp+pVxZZVXKvaJNwwrK6dZlqczKU0RBEEC7fgvMHhOZ0O21x4i0MG+4g1ckg
# HWMpLc7sXk7Ik/ghYZs06wXGXuxbGrzryc/NrDRAX7F6Zu53yEioZldXn1RYjgwr
# t0+nMNlW7sp7XeOtyU9e5TXnMcvak17cjo+A2raRmECQecN4x7axxLVqGDgDEI3Y
# 1DekLgV9iPWCPhCRcKtVgkEy19sEcypukQF8IUzUvK4bA3VdeGbZOjFEmjNAvwjX
# WkmkwuapoGfdpCe8oU85tRFYF/ckXEaPZPfBaYh2mHY9WV1CdoeJl2l6SPDgohIb
# Zpp0yt5LHucOY67m1O+SkjqePdwA5EUlibaaRBkrfsCUtNJhbesz2cXfSwQAzH0c
# lcOP9yGyshG3u3/y1YxwLEFgqrFjGESVGnZifvaAsPvoZKYz0YkH4b235kOkGLim
# dwHhD5QMIR2yVCkliWzlDlJRR3S+Jqy2QXXeeqxfjT/JvNNBERJb5RBQ6zHFynIW
# IgnffEx1P2PsIV/EIFFrb7GrhotPwtZFX50g/KEexcCPorF+CiaZ9eRpL5gdLfXZ
# qbId5RsCAwEAAaOCATowggE2MA8GA1UdEwEB/wQFMAMBAf8wHQYDVR0OBBYEFOzX
# 44LScV1kTN8uZz/nupiuHA9PMB8GA1UdIwQYMBaAFEXroq/0ksuCMS1Ri6enIZ3z
# bcgPMA4GA1UdDwEB/wQEAwIBhjB5BggrBgEFBQcBAQRtMGswJAYIKwYBBQUHMAGG
# GGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBDBggrBgEFBQcwAoY3aHR0cDovL2Nh
# Y2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNydDBF
# BgNVHR8EPjA8MDqgOKA2hjRodHRwOi8vY3JsMy5kaWdpY2VydC5jb20vRGlnaUNl
# cnRBc3N1cmVkSURSb290Q0EuY3JsMBEGA1UdIAQKMAgwBgYEVR0gADANBgkqhkiG
# 9w0BAQwFAAOCAQEAcKC/Q1xV5zhfoKN0Gz22Ftf3v1cHvZqsoYcs7IVeqRq7IviH
# GmlUIu2kiHdtvRoU9BNKei8ttzjv9P+Aufih9/Jy3iS8UgPITtAq3votVs/59Pes
# MHqai7Je1M/RQ0SbQyHrlnKhSLSZy51PpwYDE3cnRNTnf+hZqPC/Lwum6fI0POz3
# A8eHqNJMQBk1RmppVLC4oVaO7KTVPeix3P0c2PR3WlxUjG/voVA9/HYJaISfb8rb
# II01YBwCA8sgsKxYoA5AY8WYIsGyWfVVa88nq2x2zm8jLfR+cWojayL/ErhULSd+
# 2DrZ8LaHlv1b0VysGMNNn3O3AamfV6peKOK5lDGCA3YwggNyAgEBMHcwYzELMAkG
# A1UEBhMCVVMxFzAVBgNVBAoTDkRpZ2lDZXJ0LCBJbmMuMTswOQYDVQQDEzJEaWdp
# Q2VydCBUcnVzdGVkIEc0IFJTQTQwOTYgU0hBMjU2IFRpbWVTdGFtcGluZyBDQQIQ
# BUSv85SdCDmmv9s/X+VhFjANBglghkgBZQMEAgEFAKCB0TAaBgkqhkiG9w0BCQMx
# DQYLKoZIhvcNAQkQAQQwHAYJKoZIhvcNAQkFMQ8XDTI0MDkyMDA5NTUzOFowKwYL
# KoZIhvcNAQkQAgwxHDAaMBgwFgQUZvArMsLCyQ+CXc6qisnGTxmcz0AwLwYJKoZI
# hvcNAQkEMSIEIJh6Ac10dPLLew7XCP5yjPJ9Zdfy314zywnDuCQqKJKfMDcGCyqG
# SIb3DQEJEAIvMSgwJjAkMCIEINL25G3tdCLM0dRAV2hBNm+CitpVmq4zFq9NGprU
# DHgoMA0GCSqGSIb3DQEBAQUABIICACIo7aYeaCBA52XdNv6zZOOFSJFRtyzFtQNO
# SEYnePfG1o9GL2g5kDK90TM6htkLyGywK6Ji5Rg9mbWpaNLmv3x0eCJM1IXazQub
# YBRJD3vV0qDUcc/0UxjMyCuCyftvXCR2Z6c2BScsUtl96BUEhvKE5N+DY4r9yUul
# xaLTbat6HKJMBI0Hn7eW7nHuiE8DT2SQNAjH1J6jSCLb9D6dDpVg8g95VvgIms9c
# v+L006FSYVxuN3GS7htk2ezoxIXA+qp+GMVLIvYIhLOdb7v+/TvbjVgpDQAJe59i
# Vx9BXP3y71A/I3lnvMIiUe8sCEyrN00bgYFvMxbO2+q1HQ8NOa/IJBxBrp+u7eAv
# L3Aloh8V9T/vWq3ujvLzMqAxRmUz0c/E+WDJjfO8Rdh3jM8ue61MjqsT2LjaomoB
# zR3SW6VG+2cAuNccqW0fkRQFRK+Ym1Gankl6Rq7iR9/W9PHWnTJqU0Fg5oV2WAls
# ydsLwGaVsL22adisiAZwJ+FMaSUYeWIaQFe+9Gkm+EMa/u7i4M28qEYQkjM8Knsa
# zM66LaB49xPYRSutehPqUJrvGxOeKR4yRPccFa46vi1FxzNTDEKh0T+B8h0yrPAl
# PYEitYlChoazjoaNpCqZCnQbkRKCEyg2MNq4ioXVntOlZqoDD4kA3En3/QlVAug5
# DYXkfajP
# SIG # End signature block
